"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const cli_command_1 = require("@contentstack/cli-command");
class RateLimitGetCommand extends cli_command_1.Command {
    async run() {
        try {
            const rateLimit = cli_utilities_1.configHandler.get('rateLimit') || {};
            const formatLimit = (limit) => (limit ? `${limit.value}(${limit.utilize}%)` : '0');
            const tableData = Object.entries(rateLimit).map(([org, limits]) => ({
                Org: org === 'default' ? 'default' : org,
                'Get Limit': formatLimit(limits.getLimit),
                Limit: formatLimit(limits.limit),
                'Bulk Limit': formatLimit(limits.bulkLimit),
            }));
            const columns = {
                Org: {
                    minWidth: 10,
                },
                'Get Limit': {
                    minWidth: 20,
                },
                Limit: {
                    minWidth: 20,
                },
                'Bulk Limit': {
                    minWidth: 20,
                },
            };
            cli_utilities_1.cliux.table(tableData, columns, { printLine: cli_utilities_1.cliux.print });
        }
        catch (error) {
            this.log('Unable to retrieve the rate limits configuration', error instanceof Error ? error.message : error);
        }
    }
}
exports.default = RateLimitGetCommand;
RateLimitGetCommand.description = 'Get rate-limit of organizations';
RateLimitGetCommand.examples = ['$ csdx config:get:rate-limit'];
