"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const cli_command_1 = require("@contentstack/cli-command");
const interactive_1 = require("../../../utils/interactive");
class RateLimitRemoveCommand extends cli_command_1.Command {
    async run() {
        try {
            const { flags } = await this.parse(RateLimitRemoveCommand);
            let { org } = flags;
            if (!org) {
                org = await (0, interactive_1.askOrgID)();
            }
            const rateLimit = cli_utilities_1.configHandler.get('rateLimit') || {};
            if (!rateLimit[org]) {
                cli_utilities_1.cliux.print(`No rate limit found for the organization UID: ${org}`, { color: 'red' });
                return;
            }
            cli_utilities_1.configHandler.delete(`rateLimit.${org}`);
            cli_utilities_1.cliux.print(`Rate limit entry for organization UID ${org} has been removed.`, { color: 'green' });
        }
        catch (error) {
            this.log('Unable to remove the rate limit entry', error instanceof Error ? error.message : error);
        }
    }
}
exports.default = RateLimitRemoveCommand;
RateLimitRemoveCommand.description = 'Remove rate-limit of the organization';
RateLimitRemoveCommand.flags = {
    org: cli_utilities_1.flags.string({
        description: 'Provide the organization UID',
    }),
};
RateLimitRemoveCommand.examples = ['$ csdx config:remove:rate-limit --org <<org_uid>>'];
